<h1 align="center">
  <img src="https://github.com/serumstudio/anglo/raw/main/.images/anglo.png" height="250" alt="anglo">
</h1>

<h4 align="center">🪐 A modern lightweight micro web framework for Python 3.</h4>

<p align="center">
  <a href="#about">About</a> | 
  <a href="#installation">Installation</a> | 
  <a href="#usage">Usage</a> | 
  <a href="#features">Features</a> | 
  <a href="#contributors">Contributors</a> |
  <a href="#license">License</a>
</p>

# About

> **Next**: [Installation](https://github.com/serumstudio/anglo#installation) 

**Anglo** is an *open source* framework use for deploying and developing, **web applications** <br>
with modern and lightweight integration. It was created to build web applications easily and reliable.

It also comes with alot of different [features](https://github.com/serumstudio/anglo#features) that you may want to check out. Anglo was mainly <br>
built at the top of **WSGI Environment**. It serves as a full wrapper for WSGI that makes your <br>
production easier. The API wrapper for Anglo is simmilar to famous web framework, **Flask and <br>
Django.**

| [Learn More](https://serum.studio/anglo)|
|-------|


<div align="right" id="installation">
  <h1> Installation </h1>
</div>

# Usage

<div align="right" id="features">
  <h1> Features </h1>
</div>

# Contributors

<div align="right" id="license">
  <h1> License </h1>
  <p> Anglo is license under <a href="https://github.com/serumstudio/anglo/blob/main/LICENSE">MIT</a> </p>
</div>
